ShutdownObserverFn

Trait ShutdownObserverFn 

pub trait ShutdownObserverFn:
    FnOnce(DriverDispatcherRef<'_>)
    + Send
    + 'static { }
A marker trait for a function type that can be used as a shutdown observer for Dispatcher.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> ShutdownObserverFn for T
where T: FnOnce(DriverDispatcherRef<'_>) + Send + 'static,