pub struct WakeVectorRegistration { /* private fields */ }Expand description
A registration handle for a wake vector event, returned by
DriverDispatcherRef::register_wake_vector and
OnDriverDispatcher::register_wake_vector. Caller must hold on to this as long as they want
this wake vector to be active.
Automatically unregisters the wake vector from the dispatcher when dropped.
Implementations
Sourceimpl WakeVectorRegistration
impl WakeVectorRegistration
Sourcepub fn unregister(self) -> Result<(), Status>
pub fn unregister(self) -> Result<(), Status>
Unregisters the wake vector. Unlike dropping the registration, this reports failures.
Returns [Status::NOT_FOUND] if the dispatcher no longer has a wake vector registered for
this handle. That can happen if another registration for the same handle was unregistered
with empty signals, which removes the handle’s wake vector entirely.